@@ -10,7 +10,7 @@ def union(
     name: str,
     types: Tuple[Types, ...],
     *,
-    description: str = None,
+    description: Optional[str] = None,
     directives: Iterable[object] = (),
     inaccessible: bool = False,
     tags: Optional[Iterable[str]] = (),
