@@ -17,7 +17,6 @@ from typing import (
     Union,
     overload,
 )
-
 from typing_extensions import Literal
 
 from strawberry.annotation import StrawberryAnnotation
@@ -51,6 +50,7 @@ UNRESOLVED = object()
 
 class StrawberryField(dataclasses.Field):
     python_name: str
+    type_annotation: Optional[StrawberryAnnotation]
     default_resolver: Callable[[Any, str], object] = getattr
 
     def __init__(
@@ -229,6 +229,10 @@ class StrawberryField(dataclasses.Field):
         # our `type` property tries to find the field type from the global namespace
         # but it is not yet defined.
         try:
+            # Prioritise the field type over the resolver return type
+            if self.type_annotation is not None:
+                return self.type_annotation.resolve()
+
             if self.base_resolver is not None:
                 # Handle unannotated functions (such as lambdas)
                 if self.base_resolver.type is not None:
@@ -239,19 +243,26 @@ class StrawberryField(dataclasses.Field):
                     if not isinstance(self.base_resolver.type, StrawberryTypeVar):
                         return self.base_resolver.type
 
-            assert self.type_annotation is not None
+            # If we get this far it means that we don't have a field type and
+            # the resolver doesn't have a return type so all we can do is return
+            # UNRESOLVED here.
+            # This case will raise a MissingReturnAnnotationError exception in the
+            # _check_field_annotations function:
+            # https://github.com/strawberry-graphql/strawberry/blob/846f060a63cb568b3cdc0deb26c308a8d0718190/strawberry/object_type.py#L76-L80
+            return UNRESOLVED
 
-            if not isinstance(self.type_annotation, StrawberryAnnotation):
-                # TODO: This is because of dataclasses
-                return self.type_annotation
-
-            return self.type_annotation.resolve()
         except NameError:
             return UNRESOLVED
 
     @type.setter
     def type(self, type_: Any) -> None:
-        self.type_annotation = type_
+        # Note: we aren't setting a namespace here for the annotation. That
+        # happens in the `_get_fields` function in `types/type_resolver` so
+        # that we have access to the correct namespace for the object type
+        # the field is attached to.
+        self.type_annotation = StrawberryAnnotation.from_annotation(
+            type_, namespace=None
+        )
 
     # TODO: add this to arguments (and/or move it to StrawberryType)
     @property
@@ -275,7 +286,7 @@ class StrawberryField(dataclasses.Field):
         # TODO: Remove with creation of StrawberryObject. Will act same as other
         #       StrawberryTypes
         if hasattr(self.type, "_type_definition"):
-            type_definition: TypeDefinition = self.type._type_definition  # type: ignore
+            type_definition: TypeDefinition = self.type._type_definition
 
             if type_definition.is_generic:
                 type_ = type_definition
