@@ -26,6 +26,7 @@ from graphql import (
 )
 
 from strawberry.annotation import StrawberryAnnotation
+from strawberry.custom_scalar import ScalarWrapper
 from strawberry.exceptions import (
     InvalidUnionType,
     UnallowedReturnTypeForUnion,
@@ -120,7 +121,7 @@ class StrawberryUnion(StrawberryType):
             new_type: Union[StrawberryType, type]
 
             if hasattr(type_, "_type_definition"):
-                type_definition: TypeDefinition = type_._type_definition  # type: ignore
+                type_definition: TypeDefinition = type_._type_definition
 
                 if type_definition.is_generic:
                     new_type = type_definition.copy_with(type_var_map)
@@ -213,7 +214,7 @@ def union(
     name: str,
     types: Collection[Types],
     *,
-    description: str = None,
+    description: Optional[str] = None,
     directives: Iterable[object] = (),
 ) -> Union[Types]:
     """Creates a new named Union type.
@@ -233,8 +234,12 @@ def union(
 
     for _type in types:
         if not isinstance(_type, TypeVar) and not hasattr(_type, "_type_definition"):
+            if isinstance(_type, ScalarWrapper):
+                type_name = _type.wrap.__name__
+            else:
+                type_name = _type.__name__
             raise InvalidUnionType(
-                f"Type `{_type.__name__}` cannot be used in a GraphQL Union"
+                f"Type `{type_name}` cannot be used in a GraphQL Union"
             )
 
     union_definition = StrawberryUnion(
